@@ -6,5 +6,5 @@ from . import views
 
 app_name = 'nautobot_type_reapply'
 urlpatterns = [
-    path(r'reapply/<int:pk>/edit/', views.ReapplyView.as_view(), name='reapply'),
+    path(r'reapply/<uuid:pk>/edit/', views.ReapplyView.as_view(), name='reapply'),
 ]
